svn commit: r295320 - in head/sys/boot/efi: boot1 include

2016-02-05 Thread Steven Hartland
Author: smh
Date: Fri Feb  5 15:35:33 2016
New Revision: 295320
URL: https://svnweb.freebsd.org/changeset/base/295320

Log:
  Fix EFI multi device boot support
  
  Fix EFI boot support when presented with multiple valid boot partitions
  across multiple devices.
  
  It now prefers to boot from partitions that are present on the underlying
  device that the boot1 image was loaded from. This means that it will boot
  from the partitions on device the user chose from EFI boot menu in
  preference to those on other devices.
  
  Also fixed is the recovery from a failed attempt to boot, from a seemingly
  valid partition, by continuing to trying all other available partitions
  no matter what the error.
  
  boot1 now use * to signify a partition what was accepted from the preferred
  device and + otherwise.
  
  Finally some error messages where improved and DPRINTF's with slowed boot
  to aid debugging.
  
  ZFS will still be preferred over UFS when both are available on the boot
  device.
  
  Reviewed by:  imp
  MFC after:1 week
  Sponsored by: Multiplay
  Differential Revision:https://reviews.freebsd.org/D5108

Modified:
  head/sys/boot/efi/boot1/boot1.c
  head/sys/boot/efi/boot1/boot_module.h
  head/sys/boot/efi/boot1/ufs_module.c
  head/sys/boot/efi/boot1/zfs_module.c
  head/sys/boot/efi/include/efidevp.h

Modified: head/sys/boot/efi/boot1/boot1.c
==
--- head/sys/boot/efi/boot1/boot1.c Fri Feb  5 14:57:41 2016
(r295319)
+++ head/sys/boot/efi/boot1/boot1.c Fri Feb  5 15:35:33 2016
(r295320)
@@ -50,9 +50,6 @@ static const boot_module_t *boot_modules
 void putchar(int c);
 EFI_STATUS efi_main(EFI_HANDLE Ximage, EFI_SYSTEM_TABLE* Xsystab);
 
-static void try_load(const boot_module_t* mod);
-static EFI_STATUS probe_handle(EFI_HANDLE h);
-
 EFI_SYSTEM_TABLE *systab;
 EFI_BOOT_SERVICES *bs;
 static EFI_HANDLE *image;
@@ -85,20 +82,300 @@ Free(void *buf, const char *file __unuse
 }
 
 /*
- * This function only returns if it fails to load the kernel. If it
- * succeeds, it simply boots the kernel.
+ * nodes_match returns TRUE if the imgpath isn't NULL and the nodes match,
+ * FALSE otherwise.
  */
-void
-try_load(const boot_module_t *mod)
+static BOOLEAN
+nodes_match(EFI_DEVICE_PATH *imgpath, EFI_DEVICE_PATH *devpath)
+{
+   int len;
+
+   if (imgpath == NULL || imgpath->Type != devpath->Type ||
+   imgpath->SubType != devpath->SubType)
+   return (FALSE);
+
+   len = DevicePathNodeLength(imgpath);
+   if (len != DevicePathNodeLength(devpath))
+   return (FALSE);
+
+   return (memcmp(imgpath, devpath, (size_t)len) == 0);
+}
+
+/*
+ * device_paths_match returns TRUE if the imgpath isn't NULL and all nodes
+ * in imgpath and devpath match up to their respect occurances of a media
+ * node, FALSE otherwise.
+ */
+static BOOLEAN
+device_paths_match(EFI_DEVICE_PATH *imgpath, EFI_DEVICE_PATH *devpath)
 {
-   size_t bufsize, cmdsize;
-   void *buf;
+
+   if (imgpath == NULL)
+   return (FALSE);
+
+   while (!IsDevicePathEnd(imgpath) && !IsDevicePathEnd(devpath)) {
+   if (IsDevicePathType(imgpath, MEDIA_DEVICE_PATH) &&
+   IsDevicePathType(devpath, MEDIA_DEVICE_PATH))
+   return (TRUE);
+
+   if (!nodes_match(imgpath, devpath))
+   return (FALSE);
+
+   imgpath = NextDevicePathNode(imgpath);
+   devpath = NextDevicePathNode(devpath);
+   }
+
+   return (FALSE);
+}
+
+/*
+ * devpath_last returns the last non-path end node in devpath.
+ */
+static EFI_DEVICE_PATH *
+devpath_last(EFI_DEVICE_PATH *devpath)
+{
+
+   while (!IsDevicePathEnd(NextDevicePathNode(devpath)))
+   devpath = NextDevicePathNode(devpath);
+
+   return (devpath);
+}
+
+/*
+ * devpath_node_str is a basic output method for a devpath node which
+ * only understands a subset of the available sub types.
+ *
+ * If we switch to UEFI 2.x then we should update it to use:
+ * EFI_DEVICE_PATH_TO_TEXT_PROTOCOL.
+ */
+static int
+devpath_node_str(char *buf, size_t size, EFI_DEVICE_PATH *devpath)
+{
+
+   switch (devpath->Type) {
+   case MESSAGING_DEVICE_PATH:
+   switch (devpath->SubType) {
+   case MSG_ATAPI_DP: {
+   ATAPI_DEVICE_PATH *atapi;
+
+   atapi = (ATAPI_DEVICE_PATH *)(void *)devpath;
+   return snprintf(buf, size, "ata(%s,%s,0x%x)",
+   (atapi->PrimarySecondary == 1) ?  "Sec" : "Pri",
+   (atapi->SlaveMaster == 1) ?  "Slave" : "Master",
+   atapi->Lun);
+   }
+   case MSG_USB_DP: {
+   USB_DEVICE_PATH *usb;
+
+   usb = (USB_DEVICE_PATH *)devpath;
+   return snprintf(buf, size, 

svn commit: r295321 - head/sys/arm64/include

2016-02-05 Thread Andrew Turner
Author: andrew
Date: Fri Feb  5 15:38:28 2016
New Revision: 295321
URL: https://svnweb.freebsd.org/changeset/base/295321

Log:
  Implement kdb_cpu_sync_icache on arm64.
  
  Sponsored by: ABT Systems Ltd

Modified:
  head/sys/arm64/include/kdb.h

Modified: head/sys/arm64/include/kdb.h
==
--- head/sys/arm64/include/kdb.hFri Feb  5 15:35:33 2016
(r295320)
+++ head/sys/arm64/include/kdb.hFri Feb  5 15:38:28 2016
(r295321)
@@ -43,6 +43,8 @@ void kdb_cpu_set_singlestep(void);
 static __inline void
 kdb_cpu_sync_icache(unsigned char *addr, size_t size)
 {
+
+   cpu_icache_sync_range((vm_offset_t)addr, size);
 }
 
 static __inline void
___
svn-src-head@freebsd.org mailing list
https://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"


svn commit: r295319 - in head/sys: arm/allwinner/a20 arm/altera/socfpga arm/amlogic/aml8726 arm/arm arm/broadcom/bcm2835 arm/freescale/imx arm/include arm/mv/armada38x arm/mv/armadaxp arm/rockchip ...

2016-02-05 Thread Michal Meloun
Author: mmel
Date: Fri Feb  5 14:57:41 2016
New Revision: 295319
URL: https://svnweb.freebsd.org/changeset/base/295319

Log:
  ARM: Use new ARMv6 naming conventions for cache and TLB functions
  in all but ARMv4 specific files.
  Expand ARMv6 compatibility stubs in cpu-v4.h. Use physical address
  in L2 cache functions if ARM_L2_PIPT is defined.

Modified:
  head/sys/arm/allwinner/a20/a20_mp.c
  head/sys/arm/altera/socfpga/socfpga_mp.c
  head/sys/arm/amlogic/aml8726/aml8726_mp.c
  head/sys/arm/arm/db_interface.c
  head/sys/arm/arm/dump_machdep.c
  head/sys/arm/arm/fiq.c
  head/sys/arm/arm/machdep.c
  head/sys/arm/arm/minidump_machdep.c
  head/sys/arm/arm/mp_machdep.c
  head/sys/arm/arm/sys_machdep.c
  head/sys/arm/broadcom/bcm2835/bcm2836_mp.c
  head/sys/arm/freescale/imx/imx6_mp.c
  head/sys/arm/include/cpu-v4.h
  head/sys/arm/include/cpu-v6.h
  head/sys/arm/include/cpufunc.h
  head/sys/arm/include/kdb.h
  head/sys/arm/mv/armada38x/pmsu.c
  head/sys/arm/mv/armadaxp/armadaxp_mp.c
  head/sys/arm/rockchip/rk30xx_mp.c
  head/sys/arm/samsung/exynos/exynos5_mp.c
  head/sys/arm/ti/omap4/omap4_mp.c
  head/sys/arm/xilinx/zy7_mp.c
  head/sys/contrib/vchiq/interface/vchiq_arm/vchiq_2835_arm.c

Modified: head/sys/arm/allwinner/a20/a20_mp.c
==
--- head/sys/arm/allwinner/a20/a20_mp.c Fri Feb  5 14:16:42 2016
(r295318)
+++ head/sys/arm/allwinner/a20/a20_mp.c Fri Feb  5 14:57:41 2016
(r295319)
@@ -37,6 +37,7 @@ __FBSDID("$FreeBSD$");
 #include 
 #include 
 
+#include 
 #include 
 #include 
 #include 
@@ -101,8 +102,7 @@ platform_mp_start_ap(void)
) != 0)
panic("Couldn't map the CPUCFG\n");
 
-   cpu_idcache_wbinv_all();
-   cpu_l2cache_wbinv_all();
+   dcache_wbinv_poc_all();
 
bus_space_write_4(fdtbus_bs_tag, cpucfg, CPUCFG_P_REG0,
pmap_kextract((vm_offset_t)mpentry));

Modified: head/sys/arm/altera/socfpga/socfpga_mp.c
==
--- head/sys/arm/altera/socfpga/socfpga_mp.cFri Feb  5 14:16:42 2016
(r295318)
+++ head/sys/arm/altera/socfpga/socfpga_mp.cFri Feb  5 14:57:41 2016
(r295319)
@@ -41,6 +41,7 @@ __FBSDID("$FreeBSD$");
 #include 
 #include 
 
+#include 
 #include 
 #include 
 #include 
@@ -162,8 +163,7 @@ platform_mp_start_ap(void)
bus_space_write_region_4(fdtbus_bs_tag, ram, 0,
(uint32_t *)_trampoline, 8);
 
-   cpu_idcache_wbinv_all();
-   cpu_l2cache_wbinv_all();
+   dcache_wbinv_poc_all();
 
/* Put CPU1 out from reset */
bus_space_write_4(fdtbus_bs_tag, rst, MPUMODRST, 0);

Modified: head/sys/arm/amlogic/aml8726/aml8726_mp.c
==
--- head/sys/arm/amlogic/aml8726/aml8726_mp.c   Fri Feb  5 14:16:42 2016
(r295318)
+++ head/sys/arm/amlogic/aml8726/aml8726_mp.c   Fri Feb  5 14:57:41 2016
(r295319)
@@ -53,6 +53,7 @@ __FBSDID("$FreeBSD$");
 #include 
 #include 
 
+#include 
 #include 
 #include 
 #include 
@@ -485,7 +486,7 @@ platform_mp_start_ap(void)
value |= AML_SCU_CONTROL_ENABLE;
SCU_WRITE_4(AML_SCU_CONTROL_REG, value);
SCU_BARRIER(AML_SCU_CONTROL_REG);
-   cpu_idcache_wbinv_all();
+   dcache_wbinv_poc_all();
 
/* Set the boot address and power on each AP. */
paddr = pmap_kextract((vm_offset_t)mpentry);

Modified: head/sys/arm/arm/db_interface.c
==
--- head/sys/arm/arm/db_interface.c Fri Feb  5 14:16:42 2016
(r295318)
+++ head/sys/arm/arm/db_interface.c Fri Feb  5 14:57:41 2016
(r295319)
@@ -39,6 +39,7 @@ __FBSDID("$FreeBSD$");
 #include "opt_ddb.h"
 
 #include 
+#include 
 #include 
 #include 
 #include  /* just for boothowto */
@@ -53,9 +54,9 @@ __FBSDID("$FreeBSD$");
 #include 
 
 #include 
+#include 
 #include 
 #include 
-#include 
 
 #include 
 #include 
@@ -63,7 +64,7 @@ __FBSDID("$FreeBSD$");
 #include 
 #include 
 #include 
-#include 
+
 
 static int nil = 0;
 
@@ -245,11 +246,10 @@ db_write_bytes(vm_offset_t addr, size_t 
}
 
/* make sure the caches and memory are in sync */
-   cpu_icache_sync_range(addr, size);
+   icache_sync(addr, size);
 
/* In case the current page tables have been modified ... */
-   cpu_tlb_flushID();
-   cpu_cpwait();
+   tlb_flush_all();
return (0);
 }
 

Modified: head/sys/arm/arm/dump_machdep.c
==
--- head/sys/arm/arm/dump_machdep.c Fri Feb  5 14:16:42 2016
(r295318)
+++ head/sys/arm/arm/dump_machdep.c Fri Feb  5 14:57:41 2016
(r295319)
@@ -59,8 +59,7 @@ dumpsys_wbinv_all(void)
 * have already been stopped, and their flush/invalidate was done as
 * part of stopping.
 */
-   

Re: svn commit: r294560 - head/etc/rc.d

2016-02-05 Thread Devin Teske
On Fri, 2016-02-05 at 13:25 +0300, Slawa Olhovchenkov wrote:
> On Thu, Feb 04, 2016 at 03:57:19PM -0800, Bryan Drewery wrote:
> 
> > On 2/4/2016 3:28 PM, Bryan Drewery wrote:
> > > On 1/22/2016 4:14 AM, Dag-Erling Smørgrav wrote:
> > > > Author: des
> > > > Date: Fri Jan 22 12:14:08 2016
> > > > New Revision: 294560
> > > > URL: https://svnweb.freebsd.org/changeset/base/294560
> > > > 
> > > > Log:
> > > >   Do not generate RSA1 or DSA keys by default.
> > > > 
> > > > Modified:
> > > >   head/etc/rc.d/sshd
> > > > 
> > > > Modified: head/etc/rc.d/sshd
> > > > ===
> > > > ===
> > > > --- head/etc/rc.d/sshd  Fri Jan 22 12:00:56 2016(
> > > > r294559)
> > > > +++ head/etc/rc.d/sshd  Fri Jan 22 12:14:08 2016(
> > > > r294560)
> > > > @@ -20,9 +20,9 @@ configtest_cmd="sshd_configtest"
> > > >  pidfile="/var/run/${name}.pid"
> > > >  extra_commands="configtest keygen reload"
> > > >  
> > > > -: ${sshd_rsa1_enable:="yes"}
> > > > +: ${sshd_rsa1_enable:="no"}
> > > >  : ${sshd_rsa_enable:="yes"}
> > > > -: ${sshd_dsa_enable:="yes"}
> > > > +: ${sshd_dsa_enable:="no"}
> > > >  : ${sshd_ecdsa_enable:="yes"}
> > > >  : ${sshd_ed25519_enable:="yes"}
> > > >  
> > > > 
> > > 
> > > I think perhaps you should also remove these as having default
> > > paths in
> > > the .c as well and require they be enabled in the config.
> > > Otherwise a
> > > warning is given:
> > > 
> > > Feb  4 15:25:22 VM sshd[874]: error: Could not load host key:
> > > /etc/ssh/ssh_host_dsa_key
> > 
> > This happens on every login even. It's quite annoying.
> 
> And no login too.
> 

At work, IT just provisioned an Ubuntu 15.10 box, where I had to
diagnost the _exact_ same problem. Looks like Ubuntu tried the same
thing and it had the same negative result.
-- 
Devin
___
svn-src-head@freebsd.org mailing list
https://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"


svn commit: r295323 - head/sys/dev/e1000

2016-02-05 Thread Eric Joyner
Author: erj
Date: Fri Feb  5 17:14:37 2016
New Revision: 295323
URL: https://svnweb.freebsd.org/changeset/base/295323

Log:
  Update em(4) to 7.6.1; update igb(4) to 2.5.3.
  
  Major changes:
  
  - Add i219/i219(2) hardware support. (Found on Skylake generation and newer
chipsets.)
- Further to the last Skylake support diff, this one also includes support 
for
  the Lewisburg chipset (i219(3)).
  
  - Add a workaround to an igb hardware errata.
All 1G server products need to have IPv6 extension header parsing turned 
off.
This should be listed in the specification updates for current 1G server
products, e.g. for i350 it's errata #37 in this document:

http://www.intel.com/content/dam/www/public/us/en/documents/specification-updates/ethernet-controller-i350-spec-update.pdf
  
  - Avoton (i354) PHY errata workaround added
  
  And a bunch of minor fixes, as well as #defines for things that the current
  em(4)/igb(4) drivers don't implement.
  
  Differential Revision: https://reviews.freebsd.org/D3162
  Reviewed by: sbruno, marius, gnn
  Approved by: gnn
  MFC after: 2 weeks
  Sponsored by: Intel Corporation

Modified:
  head/sys/dev/e1000/e1000_80003es2lan.c
  head/sys/dev/e1000/e1000_82540.c
  head/sys/dev/e1000/e1000_82541.c
  head/sys/dev/e1000/e1000_82542.c
  head/sys/dev/e1000/e1000_82543.c
  head/sys/dev/e1000/e1000_82571.h
  head/sys/dev/e1000/e1000_82575.c
  head/sys/dev/e1000/e1000_82575.h
  head/sys/dev/e1000/e1000_api.c
  head/sys/dev/e1000/e1000_defines.h
  head/sys/dev/e1000/e1000_hw.h
  head/sys/dev/e1000/e1000_i210.c
  head/sys/dev/e1000/e1000_ich8lan.c
  head/sys/dev/e1000/e1000_ich8lan.h
  head/sys/dev/e1000/e1000_mac.h
  head/sys/dev/e1000/e1000_mbx.c
  head/sys/dev/e1000/e1000_nvm.h
  head/sys/dev/e1000/e1000_osdep.h
  head/sys/dev/e1000/e1000_phy.c
  head/sys/dev/e1000/e1000_regs.h
  head/sys/dev/e1000/if_em.c
  head/sys/dev/e1000/if_em.h
  head/sys/dev/e1000/if_igb.c

Modified: head/sys/dev/e1000/e1000_80003es2lan.c
==
--- head/sys/dev/e1000/e1000_80003es2lan.c  Fri Feb  5 16:48:03 2016
(r295322)
+++ head/sys/dev/e1000/e1000_80003es2lan.c  Fri Feb  5 17:14:37 2016
(r295323)
@@ -851,11 +851,17 @@ static s32 e1000_reset_hw_80003es2lan(st
e1000_release_phy_80003es2lan(hw);
 
/* Disable IBIST slave mode (far-end loopback) */
-   e1000_read_kmrn_reg_80003es2lan(hw, E1000_KMRNCTRLSTA_INBAND_PARAM,
-   _reg_data);
-   kum_reg_data |= E1000_KMRNCTRLSTA_IBIST_DISABLE;
-   e1000_write_kmrn_reg_80003es2lan(hw, E1000_KMRNCTRLSTA_INBAND_PARAM,
-   kum_reg_data);
+   ret_val = e1000_read_kmrn_reg_80003es2lan(hw,
+   E1000_KMRNCTRLSTA_INBAND_PARAM, _reg_data);
+   if (!ret_val) {
+   kum_reg_data |= E1000_KMRNCTRLSTA_IBIST_DISABLE;
+   ret_val = e1000_write_kmrn_reg_80003es2lan(hw,
+E1000_KMRNCTRLSTA_INBAND_PARAM,
+kum_reg_data);
+   if (ret_val)
+   DEBUGOUT("Error disabling far-end loopback\n");
+   } else
+   DEBUGOUT("Error disabling far-end loopback\n");
 
ret_val = e1000_get_auto_rd_done_generic(hw);
if (ret_val)
@@ -911,11 +917,18 @@ static s32 e1000_init_hw_80003es2lan(str
return ret_val;
 
/* Disable IBIST slave mode (far-end loopback) */
-   e1000_read_kmrn_reg_80003es2lan(hw, E1000_KMRNCTRLSTA_INBAND_PARAM,
-   _reg_data);
-   kum_reg_data |= E1000_KMRNCTRLSTA_IBIST_DISABLE;
-   e1000_write_kmrn_reg_80003es2lan(hw, E1000_KMRNCTRLSTA_INBAND_PARAM,
-kum_reg_data);
+   ret_val =
+   e1000_read_kmrn_reg_80003es2lan(hw, E1000_KMRNCTRLSTA_INBAND_PARAM,
+   _reg_data);
+   if (!ret_val) {
+   kum_reg_data |= E1000_KMRNCTRLSTA_IBIST_DISABLE;
+   ret_val = e1000_write_kmrn_reg_80003es2lan(hw,
+E1000_KMRNCTRLSTA_INBAND_PARAM,
+kum_reg_data);
+   if (ret_val)
+   DEBUGOUT("Error disabling far-end loopback\n");
+   } else
+   DEBUGOUT("Error disabling far-end loopback\n");
 
/* Set the transmit descriptor write-back policy */
reg_data = E1000_READ_REG(hw, E1000_TXDCTL(0));

Modified: head/sys/dev/e1000/e1000_82540.c
==
--- head/sys/dev/e1000/e1000_82540.cFri Feb  5 16:48:03 2016
(r295322)
+++ head/sys/dev/e1000/e1000_82540.cFri Feb  5 17:14:37 2016
(r295323)
@@ -66,7 +66,7 @@ static s32  e1000_read_mac_addr_82540(st
 

svn commit: r295329 - head/etc/periodic/daily

2016-02-05 Thread Alexander Motin
Author: mav
Date: Fri Feb  5 18:17:37 2016
New Revision: 295329
URL: https://svnweb.freebsd.org/changeset/base/295329

Log:
  Update script for modern `zpool status` output.

Modified:
  head/etc/periodic/daily/800.scrub-zfs

Modified: head/etc/periodic/daily/800.scrub-zfs
==
--- head/etc/periodic/daily/800.scrub-zfs   Fri Feb  5 18:13:55 2016
(r295328)
+++ head/etc/periodic/daily/800.scrub-zfs   Fri Feb  5 18:17:37 2016
(r295329)
@@ -78,11 +78,14 @@ case "$daily_scrub_zfs_enable" in
continue
fi
 
-   _status="$(zpool status ${pool} | grep scrub:)"
+   _status="$(zpool status ${pool} | grep scan:)"
case "${_status}" in
*"scrub in progress"*)
echo "   scrubbing of pool '${pool}' already in 
progress, skipping:"
;;
+   *"resilver in progress"*)
+   echo "   resilvering of pool '${pool}' is in 
progress, skipping:"
+   ;;
*"none requested"*)
echo "   starting first scrub (since reboot) of 
pool '${pool}':"
zpool scrub ${pool}
___
svn-src-head@freebsd.org mailing list
https://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"


Re: svn commit: r295323 - head/sys/dev/e1000

2016-02-05 Thread Alan Somers
On Fri, Feb 5, 2016 at 10:14 AM, Eric Joyner  wrote:
> Author: erj
> Date: Fri Feb  5 17:14:37 2016
> New Revision: 295323
> URL: https://svnweb.freebsd.org/changeset/base/295323
>
> Log:
>   Update em(4) to 7.6.1; update igb(4) to 2.5.3.
>
>   Major changes:
>
>   - Add i219/i219(2) hardware support. (Found on Skylake generation and newer
> chipsets.)
> - Further to the last Skylake support diff, this one also includes 
> support for
>   the Lewisburg chipset (i219(3)).
>
>   - Add a workaround to an igb hardware errata.
> All 1G server products need to have IPv6 extension header parsing turned 
> off.
> This should be listed in the specification updates for current 1G server
> products, e.g. for i350 it's errata #37 in this document:
> 
> http://www.intel.com/content/dam/www/public/us/en/documents/specification-updates/ethernet-controller-i350-spec-update.pdf
>
>   - Avoton (i354) PHY errata workaround added
>
>   And a bunch of minor fixes, as well as #defines for things that the current
>   em(4)/igb(4) drivers don't implement.
>
>   Differential Revision: https://reviews.freebsd.org/D3162
>   Reviewed by: sbruno, marius, gnn
>   Approved by: gnn
>   MFC after: 2 weeks
>   Sponsored by: Intel Corporation
>
> Modified:
>   head/sys/dev/e1000/e1000_80003es2lan.c
>   head/sys/dev/e1000/e1000_82540.c
>   head/sys/dev/e1000/e1000_82541.c
>   head/sys/dev/e1000/e1000_82542.c
>   head/sys/dev/e1000/e1000_82543.c
>   head/sys/dev/e1000/e1000_82571.h
>   head/sys/dev/e1000/e1000_82575.c
>   head/sys/dev/e1000/e1000_82575.h
>   head/sys/dev/e1000/e1000_api.c
>   head/sys/dev/e1000/e1000_defines.h
>   head/sys/dev/e1000/e1000_hw.h
>   head/sys/dev/e1000/e1000_i210.c
>   head/sys/dev/e1000/e1000_ich8lan.c
>   head/sys/dev/e1000/e1000_ich8lan.h
>   head/sys/dev/e1000/e1000_mac.h
>   head/sys/dev/e1000/e1000_mbx.c
>   head/sys/dev/e1000/e1000_nvm.h
>   head/sys/dev/e1000/e1000_osdep.h
>   head/sys/dev/e1000/e1000_phy.c
>   head/sys/dev/e1000/e1000_regs.h
>   head/sys/dev/e1000/if_em.c
>   head/sys/dev/e1000/if_em.h
>   head/sys/dev/e1000/if_igb.c
>

By any chance, might this change fix
https://bugs.freebsd.org/bugzilla/show_bug.cgi?id=205759 ?
___
svn-src-head@freebsd.org mailing list
https://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"


svn commit: r295324 - head/etc/periodic/daily

2016-02-05 Thread Alexander Motin
Author: mav
Date: Fri Feb  5 17:28:11 2016
New Revision: 295324
URL: https://svnweb.freebsd.org/changeset/base/295324

Log:
  Add error check to not leak logs with syntax errors in case of failed
  `zpool history`.
  
  MFC after:1 month

Modified:
  head/etc/periodic/daily/800.scrub-zfs

Modified: head/etc/periodic/daily/800.scrub-zfs
==
--- head/etc/periodic/daily/800.scrub-zfs   Fri Feb  5 17:14:37 2016
(r295323)
+++ head/etc/periodic/daily/800.scrub-zfs   Fri Feb  5 17:28:11 2016
(r295324)
@@ -63,6 +63,11 @@ case "$daily_scrub_zfs_enable" in
_last_scrub=$(zpool history ${pool} | \
sed -ne '2s/ .*$//p')
fi
+   if [ -z "${_last_scrub}" ]; then
+   echo "   skipping scrubbing of pool '${pool}':"
+   echo "  can't get last scrubbing date"
+   continue
+   fi
 
# Now minus last scrub (both in seconds) converted to days.
_scrub_diff=$(expr -e \( $(date +%s) - \
___
svn-src-head@freebsd.org mailing list
https://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"


Re: svn commit: r295330 - head/sys/vm

2016-02-05 Thread Gleb Smirnoff
  Mark,

  thanks! Me culpa :(

On Fri, Feb 05, 2016 at 07:35:53PM +, Mark Johnston wrote:
M> Author: markj
M> Date: Fri Feb  5 19:35:53 2016
M> New Revision: 295330
M> URL: https://svnweb.freebsd.org/changeset/base/295330
M> 
M> Log:
M>   Plug a vm_page leak introduced in r292373.
M>   
M>   Reported by:   vangyzen
M> 
M> Modified:
M>   head/sys/vm/sg_pager.c
M> 
M> Modified: head/sys/vm/sg_pager.c
M> 
==
M> --- head/sys/vm/sg_pager.c   Fri Feb  5 18:17:37 2016(r295329)
M> +++ head/sys/vm/sg_pager.c   Fri Feb  5 19:35:53 2016(r295330)
M> @@ -189,6 +189,9 @@ sg_pager_getpages(vm_object_t object, vm
M>  VM_OBJECT_WLOCK(object);
M>  TAILQ_INSERT_TAIL(>un_pager.sgp.sgp_pglist, page, plinks.q);
M>  vm_page_replace_checked(page, object, offset, m[0]);
M> +vm_page_lock(m[0]);
M> +vm_page_free(m[0]);
M> +vm_page_unlock(m[0]);
M>  m[0] = page;
M>  page->valid = VM_PAGE_BITS_ALL;
M>  
M> ___
M> svn-src-...@freebsd.org mailing list
M> https://lists.freebsd.org/mailman/listinfo/svn-src-all
M> To unsubscribe, send any mail to "svn-src-all-unsubscr...@freebsd.org"

-- 
Totus tuus, Glebius.
___
svn-src-head@freebsd.org mailing list
https://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"


svn commit: r295331 - in head/sys: kern sys

2016-02-05 Thread John Baldwin
Author: jhb
Date: Fri Feb  5 20:38:09 2016
New Revision: 295331
URL: https://svnweb.freebsd.org/changeset/base/295331

Log:
  Rename aiocblist to kaiocb and use consistent variable names.
  
  Typically list is used for a structure that holds a list head in
  FreeBSD, not for members of a list.  As such, rename 'struct aiocblist'
  to 'struct kaiocb' (the kernel version of 'struct aiocb').
  
  While here, use more consistent variable names for AIO control blocks:
  
  - Use 'job' instead of 'aiocbe', 'cb', 'cbe', or 'iocb' for kernel job
objects.
  - Use 'jobn' instead of 'cbn' for use with TAILQ_FOREACH_SAFE().
  - Use 'sjob' and 'sjobn' instead of 'scb' and 'scbn' for fsync jobs.
  - Use 'ujob' instead of 'aiocbp', 'job', 'uaiocb', or 'uuaiocb' to hold
a user pointer to a 'struct aiocb'.
  - Use 'ujobp' instead of 'aiocbp' for a user pointer to a 'struct aiocb *'.
  
  Reviewed by:  kib
  Sponsored by: Chelsio Communications
  Differential Revision:https://reviews.freebsd.org/D5125

Modified:
  head/sys/kern/vfs_aio.c
  head/sys/sys/event.h
  head/sys/sys/socketvar.h

Modified: head/sys/kern/vfs_aio.c
==
--- head/sys/vm/sg_pager.c  Fri Feb  5 18:17:37 2016(r295329)
+++ head/sys/vm/sg_pager.c  Fri Feb  5 19:35:53 2016(r295330)
@@ -189,6 +189,9 @@ sg_pager_getpages(vm_object_t object, vm
VM_OBJECT_WLOCK(object);
TAILQ_INSERT_TAIL(>un_pager.sgp.sgp_pglist, page, plinks.q);
vm_page_replace_checked(page, object, offset, m[0]);
+   vm_page_lock(m[0]);
+   vm_page_free(m[0]);
+   vm_page_unlock(m[0]);
m[0] = page;
page->valid = VM_PAGE_BITS_ALL;
 
___
svn-src-head@freebsd.org mailing list
https://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"


svn commit: r295335 - head/contrib/elftoolchain/readelf

2016-02-05 Thread Ed Maste
Author: emaste
Date: Fri Feb  5 20:56:11 2016
New Revision: 295335
URL: https://svnweb.freebsd.org/changeset/base/295335

Log:
  readelf: report value of unknown relocation types
  
  Obtained from:ELF Tool Chain r3387
  Sponsored by: The FreeBSD Foundation

Modified:
  head/contrib/elftoolchain/readelf/readelf.c

Modified: head/contrib/elftoolchain/readelf/readelf.c
==
--- head/contrib/elftoolchain/readelf/readelf.c Fri Feb  5 20:54:51 2016
(r295334)
+++ head/contrib/elftoolchain/readelf/readelf.c Fri Feb  5 20:56:11 2016
(r295335)
@@ -1053,8 +1053,9 @@ static struct {
 static const char *
 r_type(unsigned int mach, unsigned int type)
 {
+   static char s_type[32];
+
switch(mach) {
-   case EM_NONE: return "";
case EM_386:
case EM_IAMCU:
switch(type) {
@@ -1089,8 +1090,8 @@ r_type(unsigned int mach, unsigned int t
case 35: return "R_386_TLS_DTPMOD32";
case 36: return "R_386_TLS_DTPOFF32";
case 37: return "R_386_TLS_TPOFF32";
-   default: return "";
}
+   break;
case EM_AARCH64:
switch(type) {
case 0: return "R_AARCH64_NONE";
@@ -1154,8 +1155,8 @@ r_type(unsigned int mach, unsigned int t
case 1030: return "R_AARCH64_TLS_TPREL64";
case 1031: return "R_AARCH64_TLSDESC";
case 1032: return "R_AARCH64_IRELATIVE";
-   default: return "";
}
+   break;
case EM_ARM:
switch(type) {
case 0: return "R_ARM_NONE";
@@ -1206,8 +1207,8 @@ r_type(unsigned int mach, unsigned int t
case 253: return "R_ARM_RABS32";
case 254: return "R_ARM_RPC24";
case 255: return "R_ARM_RBASE";
-   default: return "";
}
+   break;
case EM_IA_64:
switch(type) {
case 0: return "R_IA_64_NONE";
@@ -1290,8 +1291,8 @@ r_type(unsigned int mach, unsigned int t
case 182: return "R_IA_64_DTPREL64MSB";
case 183: return "R_IA_64_DTPREL64LSB";
case 186: return "R_IA_64_LTOFF_DTPREL22";
-   default: return "";
}
+   break;
case EM_MIPS:
switch(type) {
case 0: return "R_MIPS_NONE";
@@ -1324,9 +1325,8 @@ r_type(unsigned int mach, unsigned int t
case 48: return "R_MIPS_TLS_TPREL64";
case 49: return "R_MIPS_TLS_TPREL_HI16";
case 50: return "R_MIPS_TLS_TPREL_LO16";
-
-   default: return "";
}
+   break;
case EM_PPC:
switch(type) {
case 0: return "R_PPC_NONE";
@@ -1406,8 +1406,8 @@ r_type(unsigned int mach, unsigned int t
case 114: return "R_PPC_EMB_RELST_HA";
case 115: return "R_PPC_EMB_BIT_FLD";
case 116: return "R_PPC_EMB_RELSDA";
-   default: return "";
}
+   break;
case EM_RISCV:
switch(type) {
case 0: return "R_RISCV_NONE";
@@ -1452,8 +1452,8 @@ r_type(unsigned int mach, unsigned int t
case 43: return "R_RISCV_ALIGN";
case 44: return "R_RISCV_RVC_BRANCH";
case 45: return "R_RISCV_RVC_JUMP";
-   default: return "";
}
+   break;
case EM_SPARC:
case EM_SPARCV9:
switch(type) {
@@ -1537,8 +1537,8 @@ r_type(unsigned int mach, unsigned int t
case 77: return "R_SPARC_TLS_DTPOFF64";
case 78: return "R_SPARC_TLS_TPOFF32";
case 79: return "R_SPARC_TLS_TPOFF64";
-   default: return "";
}
+   break;
case EM_X86_64:
switch(type) {
case 0: return "R_X86_64_NONE";
@@ -1579,10 +1579,12 @@ r_type(unsigned int mach, unsigned int t
case 35: return "R_X86_64_TLSDESC_CALL";
case 36: return "R_X86_64_TLSDESC";
case 37: return "R_X86_64_IRELATIVE";
-   default: return "";
}
-   default: return "";
+   break;
}
+
+   snprintf(s_type, sizeof(s_type), "", type);
+   return (s_type);
 }
 
 static const char *
___
svn-src-head@freebsd.org mailing list
https://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"


svn commit: r295336 - head/contrib/elftoolchain/readelf

2016-02-05 Thread Ed Maste
Author: emaste
Date: Fri Feb  5 20:57:21 2016
New Revision: 295336
URL: https://svnweb.freebsd.org/changeset/base/295336

Log:
  readelf: decode AArch64 TLS descriptor relocations
  
  From ELF for the ARM(R) 64-bit Architecture, table 4-19.
  
  Obtained from:ELF Tool Chain r3386
  Sponsored by: The FreeBSD Foundation

Modified:
  head/contrib/elftoolchain/readelf/readelf.c

Modified: head/contrib/elftoolchain/readelf/readelf.c
==
--- head/contrib/elftoolchain/readelf/readelf.c Fri Feb  5 20:56:11 2016
(r295335)
+++ head/contrib/elftoolchain/readelf/readelf.c Fri Feb  5 20:57:21 2016
(r295336)
@@ -1146,6 +1146,16 @@ r_type(unsigned int mach, unsigned int t
case 311: return "R_AARCH64_ADR_GOT_PAGE";
case 312: return "R_AARCH64_LD64_GOT_LO12_NC";
case 313: return "R_AARCH64_LD64_GOTPAGE_LO15";
+   case 560: return "R_AARCH64_TLSDESC_LD_PREL19";
+   case 561: return "R_AARCH64_TLSDESC_ADR_PREL21";
+   case 562: return "R_AARCH64_TLSDESC_ADR_PAGE21";
+   case 563: return "R_AARCH64_TLSDESC_LD64_LO12";
+   case 564: return "R_AARCH64_TLSDESC_ADD_LO12";
+   case 565: return "R_AARCH64_TLSDESC_OFF_G1";
+   case 566: return "R_AARCH64_TLSDESC_OFF_G0_NC";
+   case 567: return "R_AARCH64_TLSDESC_LDR";
+   case 568: return "R_AARCH64_TLSDESC_ADD";
+   case 569: return "R_AARCH64_TLSDESC_CALL";
case 1024: return "R_AARCH64_COPY";
case 1025: return "R_AARCH64_GLOB_DAT";
case 1026: return "R_AARCH64_JUMP_SLOT";
___
svn-src-head@freebsd.org mailing list
https://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"


svn commit: r295316 - head/sys/arm/arm

2016-02-05 Thread Svatopluk Kraus
Author: skra
Date: Fri Feb  5 10:40:01 2016
New Revision: 295316
URL: https://svnweb.freebsd.org/changeset/base/295316

Log:
  Follow up r295257 and convert also pt_memattr. This did not break
  anything as both VM_MEMATTR_WB_WA and PTE2_ATTR_WB_WA are zero.
  Correct also type of pmap_dcache_wb_pou() last argument.

Modified:
  head/sys/arm/arm/pmap-v6.c

Modified: head/sys/arm/arm/pmap-v6.c
==
--- head/sys/arm/arm/pmap-v6.c  Fri Feb  5 09:46:24 2016(r295315)
+++ head/sys/arm/arm/pmap-v6.c  Fri Feb  5 10:40:01 2016(r295316)
@@ -3,8 +3,8 @@
  * Copyright (c) 1994 John S. Dyson
  * Copyright (c) 1994 David Greenman
  * Copyright (c) 2005-2010 Alan L. Cox 
- * Copyright (c) 2014 Svatopluk Kraus 
- * Copyright (c) 2014 Michal Meloun 
+ * Copyright (c) 2014-2016 Svatopluk Kraus 
+ * Copyright (c) 2014-2016 Michal Meloun 
  * All rights reserved.
  *
  * This code is derived from software contributed to Berkeley by
@@ -223,9 +223,10 @@ int pmap_debug_level = 1;
  *  PTE2 descriptors creation macros.
  */
 #define PTE2_TEX_DEFAULT   memattr_to_tex2(VM_MEMATTR_DEFAULT)
+#define PTE2_TEX_PTmemattr_to_tex2(pt_memattr)
 
-#define PTE2_KPT(pa)   PTE2_KERN(pa, PTE2_AP_KRW, pt_memattr)
-#define PTE2_KPT_NG(pa)PTE2_KERN_NG(pa, PTE2_AP_KRW, pt_memattr)
+#define PTE2_KPT(pa)   PTE2_KERN(pa, PTE2_AP_KRW, PTE2_TEX_PT)
+#define PTE2_KPT_NG(pa)PTE2_KERN_NG(pa, PTE2_AP_KRW, PTE2_TEX_PT)
 
 #define PTE2_KRW(pa)   PTE2_KERN(pa, PTE2_AP_KRW, PTE2_TEX_DEFAULT)
 #define PTE2_KRO(pa)   PTE2_KERN(pa, PTE2_AP_KR, PTE2_TEX_DEFAULT)
@@ -6071,7 +6072,7 @@ pmap_set_pcb_pagedir(pmap_t pmap, struct
  *  The range must be within a single page.
  */
 static void
-pmap_dcache_wb_pou(vm_paddr_t pa, vm_size_t size, vm_memattr_t ma)
+pmap_dcache_wb_pou(vm_paddr_t pa, vm_size_t size, uint32_t attr)
 {
struct sysmaps *sysmaps;
 
@@ -6083,7 +6084,7 @@ pmap_dcache_wb_pou(vm_paddr_t pa, vm_siz
mtx_lock(>lock);
if (*sysmaps->CMAP3)
panic("%s: CMAP3 busy", __func__);
-   pte2_store(sysmaps->CMAP3, PTE2_KERN_NG(pa, PTE2_AP_KRW, ma));
+   pte2_store(sysmaps->CMAP3, PTE2_KERN_NG(pa, PTE2_AP_KRW, attr));
dcache_wb_pou((vm_offset_t)sysmaps->CADDR3 + (pa & PAGE_MASK), size);
pte2_clear(sysmaps->CMAP3);
tlb_flush((vm_offset_t)sysmaps->CADDR3);
___
svn-src-head@freebsd.org mailing list
https://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"


svn commit: r295317 - head/sys/arm/arm

2016-02-05 Thread Svatopluk Kraus
Author: skra
Date: Fri Feb  5 11:28:35 2016
New Revision: 295317
URL: https://svnweb.freebsd.org/changeset/base/295317

Log:
  Follow up r295257 and replace bad reference to TEX in defines,
  variables and functions. This stuff is named properly now.
  
  Thus, the VM_MEMATTR_xxx is an index to PTE2 attribute table.
  
  Pointy hat to:skra

Modified:
  head/sys/arm/arm/pmap-v6.c

Modified: head/sys/arm/arm/pmap-v6.c
==
--- head/sys/arm/arm/pmap-v6.c  Fri Feb  5 10:40:01 2016(r295316)
+++ head/sys/arm/arm/pmap-v6.c  Fri Feb  5 11:28:35 2016(r295317)
@@ -222,14 +222,14 @@ int pmap_debug_level = 1;
 /*
  *  PTE2 descriptors creation macros.
  */
-#define PTE2_TEX_DEFAULT   memattr_to_tex2(VM_MEMATTR_DEFAULT)
-#define PTE2_TEX_PTmemattr_to_tex2(pt_memattr)
+#define PTE2_ATTR_DEFAULT  vm_memattr_to_pte2(VM_MEMATTR_DEFAULT)
+#define PTE2_ATTR_PT   vm_memattr_to_pte2(pt_memattr)
 
-#define PTE2_KPT(pa)   PTE2_KERN(pa, PTE2_AP_KRW, PTE2_TEX_PT)
-#define PTE2_KPT_NG(pa)PTE2_KERN_NG(pa, PTE2_AP_KRW, PTE2_TEX_PT)
+#define PTE2_KPT(pa)   PTE2_KERN(pa, PTE2_AP_KRW, PTE2_ATTR_PT)
+#define PTE2_KPT_NG(pa)PTE2_KERN_NG(pa, PTE2_AP_KRW, PTE2_ATTR_PT)
 
-#define PTE2_KRW(pa)   PTE2_KERN(pa, PTE2_AP_KRW, PTE2_TEX_DEFAULT)
-#define PTE2_KRO(pa)   PTE2_KERN(pa, PTE2_AP_KR, PTE2_TEX_DEFAULT)
+#define PTE2_KRW(pa)   PTE2_KERN(pa, PTE2_AP_KRW, PTE2_ATTR_DEFAULT)
+#define PTE2_KRO(pa)   PTE2_KERN(pa, PTE2_AP_KR, PTE2_ATTR_DEFAULT)
 
 #define PV_STATS
 #ifdef PV_STATS
@@ -397,7 +397,7 @@ static uint32_t tex_class[8] = {
 };
 #undef TEX
 
-static uint32_t tex_attr2[8] = {
+static uint32_t pte2_attr_tab[8] = {
PTE2_ATTR_WB_WA,/* 0 - VM_MEMATTR_WB_WA */
PTE2_ATTR_NOCACHE,  /* 1 - VM_MEMATTR_NOCACHE */
PTE2_ATTR_DEVICE,   /* 2 - VM_MEMATTR_DEVICE */
@@ -414,18 +414,18 @@ CTASSERT(VM_MEMATTR_SO == 3);
 CTASSERT(VM_MEMATTR_WRITE_THROUGH == 4);
 
 static inline uint32_t
-memattr_to_tex2(vm_memattr_t ma)
+vm_memattr_to_pte2(vm_memattr_t ma)
 {
 
-   KASSERT(ma < 5, ("%s: bad vm_memattr_t %d", __func__, ma));
-   return (tex_attr2[(u_int)ma]);
+   KASSERT((u_int)ma < 5, ("%s: bad vm_memattr_t %d", __func__, ma));
+   return (pte2_attr_tab[(u_int)ma]);
 }
 
 static inline uint32_t
-page_tex2(vm_page_t m)
+vm_page_pte2_attr(vm_page_t m)
 {
 
-   return (memattr_to_tex2(m->md.pat_mode));
+   return (vm_memattr_to_pte2(m->md.pat_mode));
 }
 
 /*
@@ -805,7 +805,7 @@ pmap_bootstrap_prepare(vm_paddr_t last)
pte1_store(pte1p++, PTE1_LINK(pa));
 
/* Make section mappings for kernel. */
-   l1_attr = ATTR_TO_L1(PTE2_TEX_DEFAULT);
+   l1_attr = ATTR_TO_L1(PTE2_ATTR_DEFAULT);
pte1p = kern_pte1(KERNBASE);
for (pa = KERNEL_V2P(KERNBASE); pa < last; pa += PTE1_SIZE)
pte1_store(pte1p++, PTE1_KERN(pa, PTE1_AP_KRW, l1_attr));
@@ -1022,7 +1022,7 @@ pmap_preboot_map_attr(vm_paddr_t pa, vm_
pt2_entry_t *pte2p;
 
l2_prot = prot & VM_PROT_WRITE ? PTE2_AP_KRW : PTE2_AP_KR;
-   l2_attr = memattr_to_tex2(attr);
+   l2_attr = vm_memattr_to_pte2(attr);
l1_prot = ATTR_TO_L1(l2_prot);
l1_attr = ATTR_TO_L1(l2_attr);
 
@@ -1277,7 +1277,7 @@ PMAP_INLINE void
 pmap_kenter(vm_offset_t va, vm_paddr_t pa)
 {
 
-   pmap_kenter_prot_attr(va, pa, PTE2_AP_KRW, PTE2_TEX_DEFAULT);
+   pmap_kenter_prot_attr(va, pa, PTE2_AP_KRW, PTE2_ATTR_DEFAULT);
 }
 
 /*
@@ -1360,7 +1360,7 @@ pmap_map(vm_offset_t *virt, vm_paddr_t s
l2prot |= (prot & VM_PROT_EXECUTE) ? PTE2_X : PTE2_NX;
l1prot = ATTR_TO_L1(l2prot);
 
-   l2attr = PTE2_TEX_DEFAULT;
+   l2attr = PTE2_ATTR_DEFAULT;
l1attr = ATTR_TO_L1(l2attr);
 
va = *virt;
@@ -1594,7 +1594,8 @@ pmap_pt2pg_zero(vm_page_t m)
mtx_lock(>lock);
if (pte2_load(sysmaps->CMAP2) != 0)
panic("%s: CMAP2 busy", __func__);
-   pte2_store(sysmaps->CMAP2, PTE2_KERN_NG(pa, PTE2_AP_KRW, page_tex2(m)));
+   pte2_store(sysmaps->CMAP2, PTE2_KERN_NG(pa, PTE2_AP_KRW,
+   vm_page_pte2_attr(m)));
/*  Even VM_ALLOC_ZERO request is only advisory. */
if ((m->flags & PG_ZERO) == 0)
pagezero(sysmaps->CADDR2);
@@ -1749,10 +1750,10 @@ pmap_qenter(vm_offset_t sva, vm_page_t *
pa = VM_PAGE_TO_PHYS(m);
pte2 = pte2_load(pte2p);
if ((pte2_pa(pte2) != pa) ||
-   (pte2_attr(pte2) != page_tex2(m))) {
+   (pte2_attr(pte2) != vm_page_pte2_attr(m))) {
anychanged++;
pte2_store(pte2p, PTE2_KERN(pa, PTE2_AP_KRW,
-   page_tex2(m)));
+   vm_page_pte2_attr(m)));
}
pte2p++;
}
@@ -3802,7 +3803,7 @@ validate:
/*
 * Now validate mapping with 

Re: svn commit: r294560 - head/etc/rc.d

2016-02-05 Thread Slawa Olhovchenkov
On Thu, Feb 04, 2016 at 03:57:19PM -0800, Bryan Drewery wrote:

> On 2/4/2016 3:28 PM, Bryan Drewery wrote:
> > On 1/22/2016 4:14 AM, Dag-Erling Smørgrav wrote:
> >> Author: des
> >> Date: Fri Jan 22 12:14:08 2016
> >> New Revision: 294560
> >> URL: https://svnweb.freebsd.org/changeset/base/294560
> >>
> >> Log:
> >>   Do not generate RSA1 or DSA keys by default.
> >>
> >> Modified:
> >>   head/etc/rc.d/sshd
> >>
> >> Modified: head/etc/rc.d/sshd
> >> ==
> >> --- head/etc/rc.d/sshd Fri Jan 22 12:00:56 2016(r294559)
> >> +++ head/etc/rc.d/sshd Fri Jan 22 12:14:08 2016(r294560)
> >> @@ -20,9 +20,9 @@ configtest_cmd="sshd_configtest"
> >>  pidfile="/var/run/${name}.pid"
> >>  extra_commands="configtest keygen reload"
> >>  
> >> -: ${sshd_rsa1_enable:="yes"}
> >> +: ${sshd_rsa1_enable:="no"}
> >>  : ${sshd_rsa_enable:="yes"}
> >> -: ${sshd_dsa_enable:="yes"}
> >> +: ${sshd_dsa_enable:="no"}
> >>  : ${sshd_ecdsa_enable:="yes"}
> >>  : ${sshd_ed25519_enable:="yes"}
> >>  
> >>
> > 
> > I think perhaps you should also remove these as having default paths in
> > the .c as well and require they be enabled in the config. Otherwise a
> > warning is given:
> > 
> > Feb  4 15:25:22 VM sshd[874]: error: Could not load host key:
> > /etc/ssh/ssh_host_dsa_key
> 
> This happens on every login even. It's quite annoying.

And no login too.
___
svn-src-head@freebsd.org mailing list
https://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"

svn commit: r295342 - head/etc/defaults

2016-02-05 Thread Devin Teske
Author: dteske
Date: Sat Feb  6 02:16:48 2016
New Revision: 295342
URL: https://svnweb.freebsd.org/changeset/base/295342

Log:
  Allow rc_conf_files to be redefined in rc.conf(5)
  
  With this change, it's possible to redefine rc_conf_files (e.g.,
  sysrc rc_conf_files+=/etc/rc.conf.other) and have the boot process
  pick up settings in extra files. The sysrc(8) tool can be used to
  query/enumerate/find/manage extra files configured in this manner.
  
  Relnotes: yes

Modified:
  head/etc/defaults/rc.conf

Modified: head/etc/defaults/rc.conf
==
--- head/etc/defaults/rc.conf   Fri Feb  5 23:50:15 2016(r295341)
+++ head/etc/defaults/rc.conf   Sat Feb  6 02:16:48 2016(r295342)
@@ -716,5 +716,17 @@ if [ -z "${source_rc_confs_defined}" ]; 
;;
esac
done
+   for i in ${rc_conf_files}; do
+   case ${sourced_files} in
+   *:$i:*)
+   ;;
+   *)
+   sourced_files="${sourced_files}:$i:"
+   if [ -r $i ]; then
+   . $i
+   fi
+   ;;
+   esac
+   done
}
 fi
___
svn-src-head@freebsd.org mailing list
https://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"


svn commit: r295343 - head/etc/defaults

2016-02-05 Thread Devin Teske
Author: dteske
Date: Sat Feb  6 02:32:13 2016
New Revision: 295343
URL: https://svnweb.freebsd.org/changeset/base/295343

Log:
  Add comment to explain functionality of code
  
  Thanks to:rpokala

Modified:
  head/etc/defaults/rc.conf

Modified: head/etc/defaults/rc.conf
==
--- head/etc/defaults/rc.conf   Sat Feb  6 02:16:48 2016(r295342)
+++ head/etc/defaults/rc.conf   Sat Feb  6 02:32:13 2016(r295343)
@@ -716,6 +716,7 @@ if [ -z "${source_rc_confs_defined}" ]; 
;;
esac
done
+   # Re-do process to pick up [possibly] redined $rc_conf_files
for i in ${rc_conf_files}; do
case ${sourced_files} in
*:$i:*)
___
svn-src-head@freebsd.org mailing list
https://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"


svn commit: r295344 - head/etc/defaults

2016-02-05 Thread Devin Teske
Author: dteske
Date: Sat Feb  6 02:35:52 2016
New Revision: 295344
URL: https://svnweb.freebsd.org/changeset/base/295344

Log:
  Fix typo in a comment; s/redined/redefined/
  
  Thanks to:rpokala

Modified:
  head/etc/defaults/rc.conf

Modified: head/etc/defaults/rc.conf
==
--- head/etc/defaults/rc.conf   Sat Feb  6 02:32:13 2016(r295343)
+++ head/etc/defaults/rc.conf   Sat Feb  6 02:35:52 2016(r295344)
@@ -716,7 +716,7 @@ if [ -z "${source_rc_confs_defined}" ]; 
;;
esac
done
-   # Re-do process to pick up [possibly] redined $rc_conf_files
+   # Re-do process to pick up [possibly] redefined $rc_conf_files
for i in ${rc_conf_files}; do
case ${sourced_files} in
*:$i:*)
___
svn-src-head@freebsd.org mailing list
https://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"


svn commit: r295341 - head/tests/sys/acl

2016-02-05 Thread Garrett Cooper
Author: ngie
Date: Fri Feb  5 23:50:15 2016
New Revision: 295341
URL: https://svnweb.freebsd.org/changeset/base/295341

Log:
  Require /bin/getfacl and /bin/setfacl when running the acl tests
  
  For cases where these utilities aren't installed, the tests would fail today
  in a non-intuitive manner on sub-testcase #3 in each of the test scripts
  
  MFC after: 1 week
  Reviewed by: markj
  Sponsored by: EMC / Isilon Storage Division

Modified:
  head/tests/sys/acl/Makefile

Modified: head/tests/sys/acl/Makefile
==
--- head/tests/sys/acl/Makefile Fri Feb  5 23:46:33 2016(r295340)
+++ head/tests/sys/acl/Makefile Fri Feb  5 23:50:15 2016(r295341)
@@ -22,8 +22,14 @@ TAP_TESTS_SH+=   04
 TEST_METADATA.$t+= required_user="root"
 .endfor
 
+_ACL_PROGS=/bin/getfacl /bin/setfacl
+
 .for t in 01 03 04
-TEST_METADATA.$t+= required_programs="/sbin/zpool"
+TEST_METADATA.$t+= required_programs="/sbin/zpool ${_ACL_PROGS}"
+.endfor
+
+.for t in 00 02
+TEST_METADATA.$t+= required_programs="${_ACL_PROGS}"
 .endfor
 
 .include 
___
svn-src-head@freebsd.org mailing list
https://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"


svn commit: r295345 - head/tests/sys/acl

2016-02-05 Thread Garrett Cooper
Author: ngie
Date: Sat Feb  6 04:13:20 2016
New Revision: 295345
URL: https://svnweb.freebsd.org/changeset/base/295345

Log:
  Use basenames for getfacl, setfacl, and zpool to work around the
  fact that Jenkins hardcodes image sizes to 2GB with the FreeBSD_HEAD
  job
  
  This is to stop the unnecessary failure emails because we've gone
  over the 2GB limit
  
  MFC after: 1 week
  X-MFC with: r295341
  Sponsored by: EMC / Isilon Storage Division

Modified:
  head/tests/sys/acl/Makefile

Modified: head/tests/sys/acl/Makefile
==
--- head/tests/sys/acl/Makefile Sat Feb  6 02:35:52 2016(r295344)
+++ head/tests/sys/acl/Makefile Sat Feb  6 04:13:20 2016(r295345)
@@ -22,10 +22,10 @@ TAP_TESTS_SH+=  04
 TEST_METADATA.$t+= required_user="root"
 .endfor
 
-_ACL_PROGS=/bin/getfacl /bin/setfacl
+_ACL_PROGS=getfacl setfacl
 
 .for t in 01 03 04
-TEST_METADATA.$t+= required_programs="/sbin/zpool ${_ACL_PROGS}"
+TEST_METADATA.$t+= required_programs="zpool ${_ACL_PROGS}"
 .endfor
 
 .for t in 00 02
___
svn-src-head@freebsd.org mailing list
https://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"


Re: svn commit: r295345 - head/tests/sys/acl

2016-02-05 Thread Ngie Cooper
On Fri, Feb 5, 2016 at 8:13 PM, Garrett Cooper  wrote:
> Author: ngie
> Date: Sat Feb  6 04:13:20 2016
> New Revision: 295345
> URL: https://svnweb.freebsd.org/changeset/base/295345
>
> Log:
>   Use basenames for getfacl, setfacl, and zpool to work around the
>   fact that Jenkins hardcodes image sizes to 2GB with the FreeBSD_HEAD
>   job
>
>   This is to stop the unnecessary failure emails because we've gone
>   over the 2GB limit
>
>   MFC after: 1 week
>   X-MFC with: r295341
>   Sponsored by: EMC / Isilon Storage Division

Ugh... I misread the Jenkins output. This isn't true:

/builds/workspace/FreeBSD_HEAD/image/src/test.img: 2048.0MB (4194304
sectors) block size 32768, fragment size 4096
using 4 cylinder groups of 626.31MB, 20042 blks, 80256 inodes.
super-block backups (for fsck -b #) at:
Aborted by rodrigc <--- HERE
  64, 1282752, 2565440, 3848128,Sending interrupt signal to process

I wish this was more apparent.
___
svn-src-head@freebsd.org mailing list
https://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"
--- head/sys/kern/vfs_aio.c Fri Feb  5 19:35:53 2016(r295330)
+++ head/sys/kern/vfs_aio.c Fri Feb  5 20:38:09 2016(r295331)
@@ -196,7 +196,7 @@ typedef struct oaiocb {
 } oaiocb_t;
 
 /*
  * Below is a key of locks used to protect each member of struct aiocblist
  * aioliojob and kaioinfo and any backends.
  *
  * * - need not protected
@@ -219,10 +219,10 @@ typedef struct oaiocb {
  * daemons.
  */
 
-struct aiocblist {
-   TAILQ_ENTRY(aiocblist) list;/* (b) internal list of for backend */
-   TAILQ_ENTRY(aiocblist) plist;   /* (a) list of jobs for each backend */
-   TAILQ_ENTRY(aiocblist) allist;  /* (a) list of all jobs in proc */
+struct kaiocb {
+   TAILQ_ENTRY(kaiocb) list;   /* (b) internal list of for backend */
+   TAILQ_ENTRY(kaiocb) plist;  /* (a) list of jobs for each backend */
+   TAILQ_ENTRY(kaiocb) allist; /* (a) list of all jobs in proc */
int jobflags;   /* (a) job flags */
int jobstate;   /* (b) job state */
int inputcharge;/* (*) input blockes */
@@ -235,7 +235,7 @@ struct aiocblist {
struct  ucred *cred;/* (*) active credential when created */
struct  file *fd_file;  /* (*) pointer to file structure */
struct  aioliojob *lio; /* (*) optional lio job */
-   struct  aiocb *uuaiocb; /* (*) pointer in userspace of aiocb */
+   struct  aiocb *ujob;/* (*) pointer in userspace of aiocb */
struct  knlist klist;   /* (a) list of knotes */
struct  aiocb uaiocb;   /* (*) kernel I/O control block */
ksiginfo_t ksi; /* (a) realtime signal info */
@@ -244,10 +244,10 @@ struct aiocblist {
 };
 
 /* jobflags */
-#define AIOCBLIST_DONE 0x01
-#define AIOCBLIST_BUFDONE  0x02
-#define AIOCBLIST_RUNDOWN  0x04
-#define AIOCBLIST_CHECKSYNC0x08
+#defineKAIOCB_DONE 0x01
+#defineKAIOCB_BUFDONE  0x02
+#defineKAIOCB_RUNDOWN  0x04
+#defineKAIOCB_CHECKSYNC0x08
 
 /*
  * AIO process info
@@ -289,12 +289,12 @@ struct kaioinfo {
int kaio_count; /* (a) size of AIO queue */
int kaio_ballowed_count;/* (*) maximum number of buffers */
int kaio_buffer_count;  /* (a) number of physio buffers */
-   TAILQ_HEAD(,aiocblist) kaio_all;/* (a) all AIOs in a process */
-   TAILQ_HEAD(,aiocblist) kaio_done;   /* (a) done queue for process */
+   TAILQ_HEAD(,kaiocb) kaio_all;   /* (a) all AIOs in a process */
+   TAILQ_HEAD(,kaiocb) kaio_done;  /* (a) done queue for process */
TAILQ_HEAD(,aioliojob) kaio_liojoblist; /* (a) list of lio jobs */
-   TAILQ_HEAD(,aiocblist) kaio_jobqueue;   /* (a) job queue for process */
-   TAILQ_HEAD(,aiocblist) kaio_bufqueue;   /* (a) buffer job queue */
-   TAILQ_HEAD(,aiocblist) kaio_syncqueue;  /* (a) queue for aio_fsync */
+   TAILQ_HEAD(,kaiocb) kaio_jobqueue;  /* (a) job queue for process */
+   TAILQ_HEAD(,kaiocb) kaio_bufqueue;  /* (a) buffer job queue */
+   TAILQ_HEAD(,kaiocb) kaio_syncqueue; /* (a) queue for aio_fsync */
struct  task kaio_task; /* (*) task to kick aio processes */
 };
 
@@ -323,28 +323,28 @@ struct aiocb_ops {
 static TAILQ_HEAD(,aioproc) aio_freeproc;  /* (c) Idle daemons */
 static struct sema aio_newproc_sem;
 static struct mtx aio_job_mtx;
-static TAILQ_HEAD(,aiocblist) aio_jobs;/* (c) Async 
job list */
+static TAILQ_HEAD(,kaiocb) aio_jobs;   /* (c) Async 

svn commit: r295338 - head/usr.sbin/freebsd-update

2016-02-05 Thread Gleb Smirnoff
Author: glebius
Date: Fri Feb  5 21:57:50 2016
New Revision: 295338
URL: https://svnweb.freebsd.org/changeset/base/295338

Log:
  Provide a future release as an example, instead of a historical one.

Modified:
  head/usr.sbin/freebsd-update/freebsd-update.sh

Modified: head/usr.sbin/freebsd-update/freebsd-update.sh
==
--- head/usr.sbin/freebsd-update/freebsd-update.sh  Fri Feb  5 21:01:08 
2016(r295337)
+++ head/usr.sbin/freebsd-update/freebsd-update.sh  Fri Feb  5 21:57:50 
2016(r295338)
@@ -45,7 +45,7 @@ Options:
   (default: /etc/freebsd-update.conf)
   -F   -- Force a fetch operation to proceed
   -k KEY   -- Trust an RSA key with SHA256 hash of KEY
-  -r release   -- Target for upgrade (e.g., 6.2-RELEASE)
+  -r release   -- Target for upgrade (e.g., 11.1-RELEASE)
   -s server-- Server from which to fetch updates
   (default: update.FreeBSD.org)
   -t address   -- Mail output of cron command, if any, to address
___
svn-src-head@freebsd.org mailing list
https://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"


svn commit: r295334 - head/contrib/elftoolchain/readelf

2016-02-05 Thread Ed Maste
Author: emaste
Date: Fri Feb  5 20:54:51 2016
New Revision: 295334
URL: https://svnweb.freebsd.org/changeset/base/295334

Log:
  readelf: avoid accidental fallthrough in RISC-V relocations
  
  This would have printed an unknown RISC-V relocation type as a SPARC
  relocation.
  
  CID:  1331398
  Obtained from:ELF Tool Chain r3283
  Sponsored by: The FreeBSD Foundation

Modified:
  head/contrib/elftoolchain/readelf/readelf.c

Modified: head/contrib/elftoolchain/readelf/readelf.c
==
--- head/contrib/elftoolchain/readelf/readelf.c Fri Feb  5 20:39:33 2016
(r295333)
+++ head/contrib/elftoolchain/readelf/readelf.c Fri Feb  5 20:54:51 2016
(r295334)
@@ -1452,6 +1452,7 @@ r_type(unsigned int mach, unsigned int t
case 43: return "R_RISCV_ALIGN";
case 44: return "R_RISCV_RVC_BRANCH";
case 45: return "R_RISCV_RVC_JUMP";
+   default: return "";
@@ -196,7 +196,7 @@ typedef struct oaiocb {
 
 /*
- * Below is a key of locks used to protect each member of struct aiocblist
+ * Below is a key of locks used to protect each member of struct kaiocb
  * aioliojob and kaioinfo and any backends.
  *
}
case EM_SPARC:
case EM_SPARCV9:
___
svn-src-head@freebsd.org mailing list
https://lists.freebsd.org/mailman/listinfo/svn-src-head
To unsubscribe, send any mail to "svn-src-head-unsubscr...@freebsd.org"


svn commit: r295330 - head/sys/vm

2016-02-05 Thread Mark Johnston
Author: markj
Date: Fri Feb  5 19:35:53 2016
New Revision: 295330
URL: https://svnweb.freebsd.org/changeset/base/295330

Log:
  Plug a vm_page leak introduced in r292373.
  
  Reported by:  vangyzen

Modified:
  head/sys/vm/sg_pager.c

Modified: head/sys/vm/sg_pager.c
==